@@ -63,10 +63,10 @@ def send_notifications(email, sender, email_configuration):
     # The full path to the file that will be attached to the email.
     ATTACHMENT = LOG_PATH
 
-    # # # The HTML body of the email.
-    # file_name = email_configuration.get('HTML_File')
-
-    BODY_HTML = email_configuration.get('HTML_File')
+    # # The HTML body of the email.
+    file_name = email_configuration.get('HTML_File')
+    email_html= open(file_name)
+    BODY_HTML = email_html.read()
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
